<p align="right">
<a href="https://hits.seeyoufarm.com" ><img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2FAutoPipo%2Fpypipo&count_bg=%23AF7EE5&title_bg=%23312D2D&icon=&icon_color=%23E39999&title=visitors&edge_flat=true"/></a>
</p>

<p align="center">
  <img src="https://github.com/AutoPipo/pypipo/raw/main/pypipo/sample/logo.png" width="30%" title="logo" ></img>
</p><br>

# pypipo
### Python library to convert PIPO Painting canvas image

<h3 align="center" >Process Summary</h3>
<p align="center">
  <img src="https://github.com/AutoPipo/pypipo/raw/main/pypipo/sample/convert-process.gif" width="60%" title="task-process"></img>
</p>

<!--
## 📃 Table of Contents
- [hat is Pipo Painting?](#-what-is-pipo-painting)    
- [How to Use?](#-how-to-use)   
  -->

## 🤔 What is Pipo Painting? 

#### "Pipo Painting" is also called "Paint by Number" or "Painting by Numbers".    

> It is a kit having a board on which light markings to indicate areas to paint, and each area has a number and a corresponding numbered paint to use. 
> The kits come with little compartmentalised boxes where the numbered colour pigments are stored. 
> The users are encouraged to wash the paintbrush every time a new numbered colour is being used.


[🔗 Wikipedia Description](https://en.wikipedia.org/wiki/Paint_by_number)   
[🔗 Amazon Products](https://www.amazon.com/Pipo-Painting/s?k=Pipo+Painting)   
[🔗 Coupang Products](https://www.coupang.com/np/search?q=%ED%94%BC%ED%8F%AC%ED%8E%98%EC%9D%B8%ED%8C%85&channel=relate)     

## ⚙ How to Use?
#### Command Line
```
>>> from pypipo.convert import pipo_convert
>>> pipo_convert(INPUT_FILE_PATH, OUTPUT_FILE_PATH)
Numbering Process: 100%|█████████████████████████████████████████████████████████| 123123/123123 [00:01<00:00, 4690.58it/s]
```

<h3 align="center" >Input image</h3>
<p align="center">
  <img src="https://github.com/AutoPipo/pypipo/raw/main/pypipo/sample/sample-image.png" width="50%" title="task-process"></img>
</p>

<h3 align="center" >Output image</h3>
<p align="center">
  <img src="https://github.com/AutoPipo/pypipo/raw/main/pypipo/sample/output-image.png" width="50%" title="task-process"></img>
</p>


## 📧 Contact to us
- [Minku Koo](https://github.com/Minku-Koo) / corleone@kakao.com
- [Jiyong Park](https://github.com/Ji-yong219) / comjiyong@kakao.com  


